@@ -210,6 +210,11 @@ class H2OGAMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasGam
         return H2OTypeConverters.scalaArrayToPythonArray(value)
 
 
+    def getSplinesNonNegative(self):
+        value = self._java_obj.getSplinesNonNegative()
+        return H2OTypeConverters.scalaArrayToPythonArray(value)
+
+
     def getScale(self):
         value = self._java_obj.getScale()
         return H2OTypeConverters.scalaArrayToPythonArray(value)
